==> toggle-checkbox-1.0.0.tgz: package/toggleCheckbox.js <==
var allToggleCheckboxes = [];

function toggleCheckboxAuto($ele)
{
  if (typeof ($ele) === "undefined") {
    $ele = $("body");
  }
  $ele.find("[data-toggle-checkbox='yes']").each(function() {
    allToggleCheckboxes.push(new ToggleCheckboxObj($(this)));
  });
}

function toggleCheckboxInit($ele)
{
  allToggleCheckboxes.push(new ToggleCheckboxObj($ele));
}


function ToggleCheckboxObj($ele)
{
  var toggleCheckbox = this;
  this.$ele          = $ele;
  this.$target       = $($ele.attr("data-target"));
  this.checked       = this.$target.is(":checked");
  this.onText        = $ele.attr("data-toggle-on-text");
  this.onClass       = $ele.attr("data-toggle-on-class");
  this.offText       = $ele.attr("data-toggle-off-text");
  this.offClass      = $ele.attr("data-toggle-off-class");

  if (typeof this.onClass === "string") {
    this.onClass = this.onClass.split(" ");
  }
  if (typeof this.offClass === "string") {
    this.offClass = this.offClass.split(" ");
  }

  this.sync = function() {
    if (toggleCheckbox.checked) {
      toggleCheckbox.$ele.removeClass(toggleCheckbox.offClass).addClass(toggleCheckbox.onClass).text(toggleCheckbox.onText);
    }
    else {
      toggleCheckbox.$ele.removeClass(toggleCheckbox.onClass).addClass(toggleCheckbox.offClass).text(toggleCheckbox.offText);
    }
  }

  this.$ele.click(function() {
    if (toggleCheckbox.checked) {
      toggleCheckbox.$target.prop("checked", false);
      toggleCheckbox.checked = false;
    }
    else {
      toggleCheckbox.$target.prop("checked", true);
      toggleCheckbox.checked = true;
    }
    toggleCheckbox.sync();
  });

  this.sync();

  allToggleCheckboxes.push(this);
}


toggleCheckboxAuto();

==> toggle-checkbox-1.0.1.tgz: package/toggleCheckbox.js <==
var allToggleCheckboxes = [];

function toggleCheckboxAuto($ele)
{
  if (typeof ($ele) === "undefined") {
    $ele = $("body");
  }
  $ele.find("[data-toggle-checkbox='yes']").each(function() {
    allToggleCheckboxes.push(new ToggleCheckboxObj($(this)));
  });
}

function toggleCheckboxInit($ele)
{
  allToggleCheckboxes.push(new ToggleCheckboxObj($ele));
}


function ToggleCheckboxObj($ele)
{
  var toggleCheckbox = this;
  this.$ele          = $ele;
  this.$target       = $($ele.attr("data-target"));
  this.checked       = this.$target.is(":checked");
  this.onText        = $ele.attr("data-toggle-on-text");
  this.onClass       = $ele.attr("data-toggle-on-class");
  this.offText       = $ele.attr("data-toggle-off-text");
  this.offClass      = $ele.attr("data-toggle-off-class");

  if (typeof this.onClass === "string") {
    this.onClass = this.onClass.split(" ");
  }
  if (typeof this.offClass === "string") {
    this.offClass = this.offClass.split(" ");
  }

  this.sync = function() {
    if (toggleCheckbox.checked) {
      toggleCheckbox.$ele.removeClass(toggleCheckbox.offClass).addClass(toggleCheckbox.onClass).text(toggleCheckbox.onText);
    }
    else {
      toggleCheckbox.$ele.removeClass(toggleCheckbox.onClass).addClass(toggleCheckbox.offClass).text(toggleCheckbox.offText);
    }
  }

  this.$ele.click(function() {
    if (toggleCheckbox.checked) {
      toggleCheckbox.$target.prop("checked", false).change();
      toggleCheckbox.checked = false;
    }
    else {
      toggleCheckbox.$target.prop("checked", true).change();
      toggleCheckbox.checked = true;
    }
    toggleCheckbox.sync();
  });

  this.sync();

  allToggleCheckboxes.push(this);
}


toggleCheckboxAuto();
